

.. image:: https://img.shields.io/pypi/v/DigiPlot.svg

        
.. image:: https://img.shields.io/badge/python-3.10|3.11|3.12|3.13|3.14-blue


.. image:: https://img.shields.io/pypi/l/DigiPlot.svg


A Tkinter Code That Helps Users Digitize Curves From Plot Images.
=================================================================

See the Code at: `<https://github.com/sonofeft/DigiPlot>`_

See the Docs at: `<http://digiplot.readthedocs.org/en/latest/>`_

See PyPI page at: `<https://pypi.python.org/pypi/digiplot>`_

If a 2D plot is available only on paper or an image file, 
but the user needs the x,y data pairs in digital form, 
DigiPlot will help to create those x,y data pairs.
